@@ -192,7 +192,7 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
    * {@inheritdoc}
    */
   public function getProvider() {
-    return isset($this->definition['provider']) ? $this->definition['provider'] : NULL;
+    return $this->definition['provider'] ?? NULL;
   }
 
   /**
@@ -256,8 +256,8 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
    * {@inheritdoc}
    */
   public function getCardinality() {
-    // @todo: Allow to control this.
-    return isset($this->definition['cardinality']) ? $this->definition['cardinality'] : 1;
+    // @todo Allow to control this.
+    return $this->definition['cardinality'] ?? 1;
   }
 
   /**
@@ -371,8 +371,9 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
    *   An array of display options. Refer to
    *   \Drupal\Core\Field\FieldDefinitionInterface::getDisplayOptions() for
    *   a list of supported keys. The options should include at least a 'weight',
-   *   or specify 'type' = 'hidden'. The 'default_widget' / 'default_formatter'
-   *   for the field type will be used if no 'type' is specified.
+   *   or specify 'region' = 'hidden'. The 'default_widget' /
+   *   'default_formatter' for the field type will be used if no 'type' is
+   *   specified.
    *
    * @return static
    *   The object itself for chaining.
@@ -408,28 +409,28 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
    * {@inheritdoc}
    */
   public function getDisplayOptions($display_context) {
-    return isset($this->definition['display'][$display_context]['options']) ? $this->definition['display'][$display_context]['options'] : NULL;
+    return $this->definition['display'][$display_context]['options'] ?? NULL;
   }
 
   /**
    * {@inheritdoc}
    */
   public function isDisplayConfigurable($display_context) {
-    return isset($this->definition['display'][$display_context]['configurable']) ? $this->definition['display'][$display_context]['configurable'] : FALSE;
+    return $this->definition['display'][$display_context]['configurable'] ?? FALSE;
   }
 
   /**
    * {@inheritdoc}
    */
   public function getDefaultValueLiteral() {
-    return isset($this->definition['default_value']) ? $this->definition['default_value'] : [];
+    return $this->definition['default_value'] ?? [];
   }
 
   /**
    * {@inheritdoc}
    */
   public function getDefaultValueCallback() {
-    return isset($this->definition['default_value_callback']) ? $this->definition['default_value_callback'] : NULL;
+    return $this->definition['default_value_callback'] ?? NULL;
   }
 
   /**
@@ -485,7 +486,8 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
    *
    * @return array
    *   The initial value for the field, as a numerically indexed array of items,
-   *   each item being a property/value array (array() for no default value).
+   *   each item being a property/value array. An empty array when there is no
+   *   default value.
    */
   public function getInitialValue() {
     return $this->normalizeValue($this->definition['initial_value'], $this->getMainPropertyName());
@@ -524,7 +526,7 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
    *   The field name.
    */
   public function getInitialValueFromField() {
-    return isset($this->definition['initial_value_from_field']) ? $this->definition['initial_value_from_field'] : NULL;
+    return $this->definition['initial_value_from_field'] ?? NULL;
   }
 
   /**
@@ -564,14 +566,17 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
       $items = $entity->get($this->getName());
       return \Drupal::service('plugin.manager.field.field_type')->createFieldItem($items, 0);
     }
-    // @todo: Allow setting custom options provider, see
-    // https://www.drupal.org/node/2002138.
+    // @todo Allow setting custom options provider.
+    //   https://www.drupal.org/node/2002138
   }
 
   /**
    * {@inheritdoc}
    */
-  public function getPropertyDefinition($name) {
+  public function getPropertyDefinition(/* string */ $name) {
+    if (!is_string($name)) {
+      @trigger_error('Calling ' . __CLASS__ . '::getPropertyDefinition() with a non-string $name is deprecated in drupal:11.3.0 and throws an exception in drupal:12.0.0. See https://www.drupal.org/node/3557373', E_USER_DEPRECATED);
+    }
     if (!isset($this->propertyDefinitions)) {
       $this->getPropertyDefinitions();
     }
@@ -609,7 +614,7 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
   /**
    * {@inheritdoc}
    */
-  public function __sleep() {
+  public function __sleep(): array {
     // Do not serialize the statically cached property definitions.
     $vars = get_object_vars($this);
     unset($vars['propertyDefinitions'], $vars['typedDataManager']);
@@ -620,7 +625,7 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
    * {@inheritdoc}
    */
   public function getTargetEntityTypeId() {
-    return isset($this->definition['entity_type']) ? $this->definition['entity_type'] : NULL;
+    return $this->definition['entity_type'] ?? NULL;
   }
 
   /**
@@ -640,7 +645,7 @@ class BaseFieldDefinition extends ListDataDefinition implements FieldDefinitionI
    * {@inheritdoc}
    */
   public function getTargetBundle() {
-    return isset($this->definition['bundle']) ? $this->definition['bundle'] : NULL;
+    return $this->definition['bundle'] ?? NULL;
   }
 
   /**
