@@ -19,13 +19,16 @@ class DirectoryWithMetadataPluginDiscovery extends YamlDiscovery {
    * @param string $file_cache_key_suffix
    *   The file cache key suffix. This should be unique for each type of
    *   discovery.
-   * @param \Drupal\Core\File\FileSystemInterface $file_system
+   * @param \Drupal\Core\File\FileSystemInterface|null $file_system
    *   The file system service.
    */
-  public function __construct(array $directories, $file_cache_key_suffix, FileSystemInterface $file_system) {
+  public function __construct(array $directories, $file_cache_key_suffix, ?FileSystemInterface $file_system = NULL) {
     // Intentionally does not call parent constructor as this class uses a
     // different YAML discovery.
-    $this->discovery = new DirectoryWithMetadataDiscovery($directories, $file_cache_key_suffix, $file_system);
+    if ($file_system) {
+      @trigger_error(sprintf('Passing the $fileSystem parameter to %s() is deprecated in drupal:11.3.0 and is removed from drupal:12.0.0. The class no longer uses the file system service. See https://www.drupal.org/node/3530869', __METHOD__), E_USER_DEPRECATED);
+    }
+    $this->discovery = new DirectoryWithMetadataDiscovery($directories, $file_cache_key_suffix);
   }
 
 }
