@@ -2,10 +2,13 @@
 
 namespace Drupal\Core\Test;
 
+use Drupal\Component\DependencyInjection\ContainerInterface;
 use Drupal\Core\Database\Database;
 
 /**
  * Provides a trait for shared test setup functionality.
+ *
+ * @property \Drupal\Component\DependencyInjection\ContainerInterface $container
  */
 trait TestSetupTrait {
 
@@ -26,11 +29,11 @@ trait TestSetupTrait {
   ];
 
   /**
-   * The dependency injection container used in the test.
+   * Stores the container in case it is set before available with \Drupal.
    *
-   * @var \Symfony\Component\DependencyInjection\ContainerInterface
+   * @see \Drupal::getContainer()
    */
-  protected $container;
+  private ?ContainerInterface $privateContainer = NULL;
 
   /**
    * The site directory of this test run.
@@ -42,9 +45,9 @@ trait TestSetupTrait {
   /**
    * The public file directory for the test environment.
    *
-   * @see \Drupal\Tests\BrowserTestBase::prepareEnvironment()
-   *
    * @var string
+   *
+   * @see \Drupal\Tests\BrowserTestBase::prepareEnvironment()
    */
   protected $publicFilesDirectory;
 
@@ -58,18 +61,18 @@ trait TestSetupTrait {
   /**
    * The private file directory for the test environment.
    *
-   * @see \Drupal\Tests\BrowserTestBase::prepareEnvironment()
-   *
    * @var string
+   *
+   * @see \Drupal\Tests\BrowserTestBase::prepareEnvironment()
    */
   protected $privateFilesDirectory;
 
   /**
    * Set to TRUE to strict check all configuration saved.
    *
-   * @see \Drupal\Core\Config\Testing\ConfigSchemaChecker
-   *
    * @var bool
+   *
+   * @see \Drupal\Core\Config\Testing\ConfigSchemaChecker
    */
   protected $strictConfigSchema = TRUE;
 
@@ -100,10 +103,10 @@ trait TestSetupTrait {
    * This value has to match the temporary directory created in
    * install_base_system() for test installs.
    *
+   * @var string
+   *
    * @see \Drupal\Tests\BrowserTestBase::prepareEnvironment()
    * @see install_base_system()
-   *
-   * @var string
    */
   protected $tempFilesDirectory;
 
@@ -134,7 +137,7 @@ trait TestSetupTrait {
    * @see \Drupal\Tests\BrowserTestBase::prepareEnvironment()
    * @see drupal_valid_test_ua()
    */
-  protected function prepareDatabasePrefix() {
+  protected function prepareDatabasePrefix(): void {
     $test_db = new TestDatabase();
     $this->siteDirectory = $test_db->getTestSitePath();
     $this->databasePrefix = $test_db->getDatabasePrefix();
@@ -143,7 +146,7 @@ trait TestSetupTrait {
   /**
    * Changes the database connection to the prefixed one.
    */
-  protected function changeDatabasePrefix() {
+  protected function changeDatabasePrefix(): void {
     if (empty($this->databasePrefix)) {
       $this->prepareDatabasePrefix();
     }
@@ -154,7 +157,7 @@ trait TestSetupTrait {
       // Ensure no existing database gets in the way. If a default database
       // exists already it must be removed.
       Database::removeConnection('default');
-      $database = Database::convertDbUrlToConnectionInfo($db_url, $this->root ?? DRUPAL_ROOT, TRUE);
+      $database = Database::convertDbUrlToConnectionInfo($db_url, TRUE);
       Database::addConnectionInfo('default', 'default', $database);
     }
 
@@ -194,4 +197,40 @@ trait TestSetupTrait {
     return array_unique(array_merge(...$exceptions));
   }
 
+  /**
+   * Implements the magic method for getting object properties.
+   *
+   * Ensures \Drupal::getContainer() is used when getting the container
+   * property, if possible.
+   */
+  public function __get($name): mixed {
+    if ($name === 'container') {
+      return \Drupal::hasContainer() ? \Drupal::getContainer() : $this->privateContainer;
+    }
+
+    trigger_error('Undefined property ' . __CLASS__ . "::\${$name}", E_USER_WARNING);
+    return NULL;
+  }
+
+  /**
+   * Implements the magic method for setting object properties.
+   *
+   * Ensures \Drupal::getContainer() is used when getting the container
+   * property, if possible.
+   */
+  public function __set($name, $value): void {
+    if ($name === 'container') {
+      $this->privateContainer = $value;
+      return;
+    }
+
+    // This deprecation message is intended to match the one PHP 8.2+ emits for
+    // dynamic properties. The magic setter and this deprecation message will
+    // be removed once property hooks can be used.
+    // @see https://www.drupal.org/project/drupal/issues/3558863
+    // @phpcs:ignore Drupal.Semantics.FunctionTriggerError.TriggerErrorTextLayoutRelaxed
+    trigger_error('Creation of dynamic property ' . __CLASS__ . "::\${$name} is deprecated", E_USER_DEPRECATED);
+    $this->$name = $value;
+  }
+
 }
