@@ -4,12 +4,14 @@ declare(strict_types=1);
 
 namespace Drupal\Tests\file\Functional;
 
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
+
 /**
  * Tests the file uploading functions.
- *
- * @group file
- * @group #slow
  */
+#[Group('file')]
+#[RunTestsInSeparateProcesses]
 class RemoteFileSaveUploadTest extends SaveUploadTest {
 
   /**
