@@ -5,17 +5,20 @@ declare(strict_types=1);
 namespace Drupal\Tests\migrate_drupal_ui\Functional\d7;
 
 use Drupal\Tests\migrate_drupal_ui\Functional\MultilingualReviewPageTestBase;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\IgnoreDeprecations;
+use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
 
 // cspell:ignore Filefield Flexslider Multiupload Imagefield rulesets
-
 /**
  * Tests migrate upgrade review page for Drupal 7.
  *
  * Tests with translation modules enabled.
- *
- * @group migrate_drupal_7
- * @group migrate_drupal_ui
  */
+#[Group('migrate_drupal_7')]
+#[Group('migrate_drupal_ui')]
+#[IgnoreDeprecations]
+#[RunTestsInSeparateProcesses]
 class MultilingualReviewPageTest extends MultilingualReviewPageTestBase {
 
   /**
@@ -44,14 +47,14 @@ class MultilingualReviewPageTest extends MultilingualReviewPageTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function getSourceBasePath() {
+  protected function getSourceBasePath(): string {
     return __DIR__ . '/files';
   }
 
   /**
    * {@inheritdoc}
    */
-  protected function getAvailablePaths() {
+  protected function getAvailablePaths(): array {
     return [
       'Block languages',
       'Blog',
@@ -59,7 +62,6 @@ class MultilingualReviewPageTest extends MultilingualReviewPageTestBase {
       'Chaos tools',
       'Chaos Tools (CTools) AJAX Example',
       'Comment',
-      'Contact',
       'Content translation',
       'Contextual links',
       'Custom content panes',
@@ -138,7 +140,7 @@ class MultilingualReviewPageTest extends MultilingualReviewPageTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function getMissingPaths() {
+  protected function getMissingPaths(): array {
     return [
       // Action is set not_finished in migrate_state_not_finished_test.
       'Aggregator',
@@ -147,6 +149,7 @@ class MultilingualReviewPageTest extends MultilingualReviewPageTestBase {
       'Book',
       'Breakpoints',
       'Color',
+      'Contact',
       'Contact translation',
       'Entity Translation Menu',
       'Entity Translation Upgrade',
