@@ -1,51 +1,62 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Drupal\Tests\path\Kernel;
 
 use Drupal\KernelTests\KernelTestBase;
 use Drupal\language\Entity\ConfigurableLanguage;
 use Drupal\node\Entity\Node;
 use Drupal\node\Entity\NodeType;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
 
+// cspell:ignore furchtbar
 /**
  * Tests loading and storing data using PathItem.
- *
- * @group path
  */
+#[Group('path')]
+#[RunTestsInSeparateProcesses]
 class PathItemTest extends KernelTestBase {
 
-  /**
-   * Modules to enable.
-   *
-   * @var array
-   */
-  public static $modules = ['path', 'node', 'user', 'system', 'language', 'content_translation'];
-
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected static $modules = [
+    'path',
+    'path_alias',
+    'node',
+    'user',
+    'language',
+  ];
+
+  /**
+   * {@inheritdoc}
+   */
+  protected function setUp(): void {
     parent::setUp();
 
     $this->installEntitySchema('node');
     $this->installEntitySchema('user');
+    $this->installEntitySchema('path_alias');
 
     $this->installSchema('node', ['node_access']);
 
-    $node_type = NodeType::create(['type' => 'foo']);
-    $node_type->save();
+    NodeType::create([
+      'type' => 'foo',
+      'name' => 'Foo',
+    ])->save();
 
     $this->installConfig(['language']);
     ConfigurableLanguage::createFromLangcode('de')->save();
   }
 
   /**
-   * Test creating, loading, updating and deleting aliases through PathItem.
+   * Tests creating, loading, updating and deleting aliases through PathItem.
    */
-  public function testPathItem() {
-
-    /** @var \Drupal\Core\Path\AliasStorageInterface $alias_storage */
-    $alias_storage = \Drupal::service('path.alias_storage');
+  public function testPathItem(): void {
+    /** @var \Drupal\path_alias\AliasRepositoryInterface $alias_repository */
+    $alias_repository = \Drupal::service('path_alias.repository');
 
     $node_storage = \Drupal::entityTypeManager()->getStorage('node');
 
@@ -61,8 +72,8 @@ class PathItemTest extends KernelTestBase {
     $this->assertFalse($node->get('path')->isEmpty());
     $this->assertEquals('/foo', $node->get('path')->alias);
 
-    $stored_alias = $alias_storage->lookupPathAlias('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
-    $this->assertEquals('/foo', $stored_alias);
+    $stored_alias = $alias_repository->lookupBySystemPath('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
+    $this->assertEquals('/foo', $stored_alias['alias']);
 
     $node_storage->resetCache();
 
@@ -96,10 +107,10 @@ class PathItemTest extends KernelTestBase {
     $translation = $loaded_node->getTranslation('de');
     $this->assertEquals('/furchtbar', $translation->path->alias);
 
-    $stored_alias = $alias_storage->lookupPathAlias('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
-    $this->assertEquals('/foo', $stored_alias);
-    $stored_alias = $alias_storage->lookupPathAlias('/' . $node->toUrl()->getInternalPath(), $translation->language()->getId());
-    $this->assertEquals('/furchtbar', $stored_alias);
+    $stored_alias = $alias_repository->lookupBySystemPath('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
+    $this->assertEquals('/foo', $stored_alias['alias']);
+    $stored_alias = $alias_repository->lookupBySystemPath('/' . $node->toUrl()->getInternalPath(), $translation->language()->getId());
+    $this->assertEquals('/furchtbar', $stored_alias['alias']);
 
     $loaded_node->get('path')->alias = '/bar';
     $this->assertFalse($loaded_node->get('path')->isEmpty());
@@ -122,11 +133,11 @@ class PathItemTest extends KernelTestBase {
     $this->assertFalse($loaded_node->get('path')->isEmpty());
     $this->assertEquals('/bar', $loaded_node->get('path')->alias);
 
-    $stored_alias = $alias_storage->lookupPathAlias('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
-    $this->assertEquals('/bar', $stored_alias);
+    $stored_alias = $alias_repository->lookupBySystemPath('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
+    $this->assertEquals('/bar', $stored_alias['alias']);
 
-    $old_alias = $alias_storage->lookupPathSource('/foo', $node->language()->getId());
-    $this->assertFalse($old_alias);
+    $old_alias = $alias_repository->lookupByAlias('/foo', $node->language()->getId());
+    $this->assertNull($old_alias);
 
     // Reload the node to make sure that it is possible to set a value
     // immediately after loading.
@@ -139,19 +150,19 @@ class PathItemTest extends KernelTestBase {
     $loaded_node = $node_storage->load($node->id());
     $this->assertFalse($loaded_node->get('path')->isEmpty());
     $this->assertEquals('/foobar', $loaded_node->get('path')->alias);
-    $stored_alias = $alias_storage->lookupPathAlias('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
-    $this->assertEquals('/foobar', $stored_alias);
+    $stored_alias = $alias_repository->lookupBySystemPath('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
+    $this->assertEquals('/foobar', $stored_alias['alias']);
 
-    $old_alias = $alias_storage->lookupPathSource('/bar', $node->language()->getId());
-    $this->assertFalse($old_alias);
+    $old_alias = $alias_repository->lookupByAlias('/bar', $node->language()->getId());
+    $this->assertNull($old_alias);
 
     $loaded_node->get('path')->alias = '';
     $this->assertEquals('', $loaded_node->get('path')->alias);
 
     $loaded_node->save();
 
-    $stored_alias = $alias_storage->lookupPathAlias('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
-    $this->assertFalse($stored_alias);
+    $stored_alias = $alias_repository->lookupBySystemPath('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
+    $this->assertNull($stored_alias);
 
     // Check that reading, updating and reading the computed alias again in the
     // same request works without clearing any caches in between.
@@ -161,16 +172,16 @@ class PathItemTest extends KernelTestBase {
 
     $this->assertFalse($loaded_node->get('path')->isEmpty());
     $this->assertEquals('/foo', $loaded_node->get('path')->alias);
-    $stored_alias = $alias_storage->lookupPathAlias('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
-    $this->assertEquals('/foo', $stored_alias);
+    $stored_alias = $alias_repository->lookupBySystemPath('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
+    $this->assertEquals('/foo', $stored_alias['alias']);
 
     $loaded_node->get('path')->alias = '/foobar';
     $loaded_node->save();
 
     $this->assertFalse($loaded_node->get('path')->isEmpty());
     $this->assertEquals('/foobar', $loaded_node->get('path')->alias);
-    $stored_alias = $alias_storage->lookupPathAlias('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
-    $this->assertEquals('/foobar', $stored_alias);
+    $stored_alias = $alias_repository->lookupBySystemPath('/' . $node->toUrl()->getInternalPath(), $node->language()->getId());
+    $this->assertEquals('/foobar', $stored_alias['alias']);
 
     // Check that \Drupal\Core\Field\FieldItemList::equals() for the path field
     // type.
