@@ -5,10 +5,14 @@ declare(strict_types=1);
 namespace Drupal\Tests\shortcut\Functional\Rest;
 
 use Drupal\Tests\rest\Functional\CookieResourceTestTrait;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
 
 /**
- * @group rest
+ * Tests Shortcut Set Json Cookie.
  */
+#[Group('rest')]
+#[RunTestsInSeparateProcesses]
 class ShortcutSetJsonCookieTest extends ShortcutSetResourceTestBase {
 
   use CookieResourceTestTrait;
