@@ -5,12 +5,14 @@ declare(strict_types=1);
 namespace Drupal\Tests\system\Functional\Extension;
 
 use Drupal\Tests\BrowserTestBase;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
 
 /**
  * Tests the LegacyHook attribute.
- *
- * @group Hook
  */
+#[Group('Hook')]
+#[RunTestsInSeparateProcesses]
 class LegacyHookTest extends BrowserTestBase {
 
   /**
