@@ -116,13 +116,14 @@ class ViewEditForm extends ViewFormBase {
     /** @var \Drupal\views_ui\ViewUI $view */
     $view = $this->entity;
     $display_id = $this->displayID;
-    // Do not allow the form to be cached, because $form_state->get('view') can become
-    // stale between page requests.
+    // Do not allow the form to be cached, because $form_state->get('view') can
+    // become stale between page requests.
     // See views_ui_ajax_get_form() for how this affects #ajax.
     // @todo To remove this and allow the form to be cacheable:
-    //   - Change $form_state->get('view') to $form_state->getTemporary()['view'].
-    //   - Add a #process function to initialize $form_state->getTemporary()['view']
-    //     on cached form submissions.
+    //   - Change $form_state->get('view') to
+    //     $form_state->getTemporary()['view'].
+    //   - Add a #process function to initialize
+    //     $form_state->getTemporary()['view'] on cached form submissions.
     //   - Use \Drupal\Core\Form\FormStateInterface::loadInclude().
     $form_state->disableCache();
 
@@ -209,7 +210,7 @@ class ViewEditForm extends ViewFormBase {
         }
       }
 
-      // Add the edit display content
+      // Add the edit display content.
       $tab_content = $this->getDisplayTab($view);
       $tab_content['#theme_wrappers'] = ['container'];
       $tab_content['#attributes'] = ['class' => ['views-display-tab']];
@@ -310,13 +311,15 @@ class ViewEditForm extends ViewFormBase {
         $displays[$new_id] = $displays[$id];
         unset($displays[$id]);
 
-        // Redirect the user to the renamed display to be sure that the page itself exists and doesn't throw errors.
+        // Redirect the user to the renamed display to be sure that the page
+        // itself exists and doesn't throw errors.
         $form_state->setRedirect('entity.view.edit_display_form', [
           'view' => $view->id(),
           'display_id' => $new_id,
         ]);
 
-        // Find attachments attached to old display id and attach them with new id.
+        // Find attachments attached to old display id and attach them with new
+        // id.
         if ($attachments) {
           foreach ($attachments as $attachment) {
             $attached_options = $executable->displayHandlers->get($attachment)->getOption('displays');
@@ -337,7 +340,8 @@ class ViewEditForm extends ViewFormBase {
     $destination = $query->get('destination');
 
     if (!empty($destination)) {
-      // Find out the first display which has a changed path and redirect to this URL.
+      // Find out the first display which has a changed path and redirect to
+      // this URL.
       $old_view = Views::getView($view->id());
       $old_view->initDisplay();
       foreach ($old_view->displayHandlers as $id => $display) {
@@ -477,7 +481,7 @@ class ViewEditForm extends ViewFormBase {
                 $url = Url::fromUri("base:$path");
               }
             }
-            catch (BadRequestException | NotAcceptableHttpException $e) {
+            catch (BadRequestException | NotAcceptableHttpException) {
               $url = '/' . $path;
             }
 
@@ -572,11 +576,8 @@ class ViewEditForm extends ViewFormBase {
     $build['columns']['second']['empty'] = [];
     $build['columns']['second']['pager'] = [];
 
-    // The third column buckets are wrapped in details.
     $build['columns']['third'] = [
-      '#type' => 'details',
-      '#title' => $this->t('Advanced'),
-      '#theme_wrappers' => ['details'],
+      '#theme_wrappers' => ['container'],
       '#attributes' => [
         'class' => [
           'views-display-column',
@@ -584,14 +585,13 @@ class ViewEditForm extends ViewFormBase {
         ],
       ],
     ];
-    // Collapse the details by default.
-    $build['columns']['third']['#open'] = \Drupal::config('views.settings')->get('ui.show.advanced_column');
 
-    // Each option (e.g. title, access, display as grid/table/list) fits into one
-    // of several "buckets," or boxes (Format, Fields, Sort, and so on).
+    // Each option (e.g. title, access, display as grid/table/list) fits into
+    // one of several "buckets," or boxes (Format, Fields, Sort, and so on).
     $buckets = [];
 
-    // Fetch options from the display plugin, with a list of buckets they go into.
+    // Fetch options from the display plugin, with a list of buckets they go
+    // into.
     $options = [];
     $view->getExecutable()->displayHandlers->get($display['id'])->optionsSummary($buckets, $options);
 
@@ -607,8 +607,8 @@ class ViewEditForm extends ViewFormBase {
       if (isset($bucket['column']) && isset($build['columns'][$bucket['column']])) {
         $column = $bucket['column'];
       }
-      // If a bucket doesn't pick one of our predefined columns to belong to, put
-      // it in the last one.
+      // If a bucket doesn't pick one of our predefined columns to belong to,
+      // put it in the last one.
       else {
         $column = 'third';
       }
@@ -642,13 +642,13 @@ class ViewEditForm extends ViewFormBase {
    */
   public function submitDisplayUndoDelete($form, FormStateInterface $form_state) {
     $view = $this->entity;
-    // Create the new display
+    // Create the new display.
     $id = $form_state->get('display_id');
     $displays = $view->get('display');
     $displays[$id]['deleted'] = FALSE;
     $view->set('display', $displays);
 
-    // Store in cache
+    // Store in cache.
     $view->cacheSet();
 
     // Redirect to the top-level edit page.
@@ -664,10 +664,10 @@ class ViewEditForm extends ViewFormBase {
   public function submitDisplayEnable($form, FormStateInterface $form_state) {
     $view = $this->entity;
     $id = $form_state->get('display_id');
-    // setOption doesn't work because this would might affect upper displays
+    // setOption doesn't work because this would might affect upper displays.
     $view->getExecutable()->displayHandlers->get($id)->setOption('enabled', TRUE);
 
-    // Store in cache
+    // Store in cache.
     $view->cacheSet();
 
     // Redirect to the top-level edit page.
@@ -685,7 +685,7 @@ class ViewEditForm extends ViewFormBase {
     $id = $form_state->get('display_id');
     $view->getExecutable()->displayHandlers->get($id)->setOption('enabled', FALSE);
 
-    // Store in cache
+    // Store in cache.
     $view->cacheSet();
 
     // Redirect to the top-level edit page.
@@ -733,7 +733,8 @@ class ViewEditForm extends ViewFormBase {
     $build = $this->getDisplayTab($view);
     $response->addCommand(new HtmlCommand('#views-tab-' . $display_id, $build));
 
-    // Regenerate the top area so changes to display names and order will appear.
+    // Regenerate the top area so changes to display names and order will
+    // appear.
     $build = $this->renderDisplayTop($view);
     $response->addCommand(new ReplaceCommand('#views-display-top', $build));
   }
@@ -747,7 +748,7 @@ class ViewEditForm extends ViewFormBase {
     $element['#attributes']['class'] = ['views-display-top', 'clearfix'];
     $element['#attributes']['id'] = ['views-display-top'];
 
-    // Extra actions for the display
+    // Extra actions for the display.
     $element['extra_actions'] = [
       '#type' => 'dropbutton',
       '#attributes' => [
@@ -823,8 +824,8 @@ class ViewEditForm extends ViewFormBase {
           'class' => ['add-display'],
           'data-drupal-dropdown-label' => $label,
         ],
-        // Allow JavaScript to remove the 'Add ' prefix from the button label when
-        // placing the button in an "Add" dropdown menu.
+        // Allow JavaScript to remove the 'Add ' prefix from the button label
+        // when placing the button in an "Add" dropdown menu.
         '#process' => array_merge(['views_ui_form_button_was_clicked'], $this->elementInfo->getInfoProperty('submit', '#process', [])),
         '#values' => [$this->t('Add @display', ['@display' => $label]), $label],
       ];
@@ -852,8 +853,8 @@ class ViewEditForm extends ViewFormBase {
    * the SharedTempStore rather than $form_state->setRebuild(). Without this
    * submit handler, buttons that add or remove displays would redirect to the
    * destination parameter (e.g., when the Edit View form is linked to from a
-   * contextual link). This handler can be added to buttons whose form submission
-   * should not yet redirect to the destination.
+   * contextual link). This handler can be added to buttons whose form
+   * submission should not yet redirect to the destination.
    */
   public function submitDelayDestination($form, FormStateInterface $form_state) {
     $request = $this->requestStack->getCurrentRequest();
@@ -1078,7 +1079,7 @@ class ViewEditForm extends ViewFormBase {
       ];
     }
 
-    // Render the array of links
+    // Render the array of links.
     $build['#actions'] = [
       '#type' => 'dropbutton',
       '#links' => $actions,
@@ -1193,7 +1194,8 @@ class ViewEditForm extends ViewFormBase {
       }
     }
 
-    // If using grouping, re-order fields so that they show up properly in the list.
+    // If using grouping, re-order fields so that they show up properly in the
+    // list.
     if ($type == 'filter' && $grouping) {
       $store = $build['fields'];
       $build['fields'] = [];
