@@ -4,14 +4,16 @@ declare(strict_types=1);
 
 namespace Drupal\Tests\views_ui\Functional;
 
-use Drupal\views\Views;
 use Drupal\views\Entity\View;
+use Drupal\views\Views;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
 
 /**
  * Tests query plugins.
- *
- * @group views_ui
  */
+#[Group('views_ui')]
+#[RunTestsInSeparateProcesses]
 class QueryTest extends UITestBase {
 
   /**
